@@ -3,7 +3,7 @@ from typing import Union
 
 from spacy.language import Language
 
-from .conceptualizer import ConceptualSpacy
+from .conceptualizer import Conceptualizer
 
 
 @Language.factory(
@@ -13,4 +13,4 @@ from .conceptualizer import ConceptualSpacy
 def make_concise_concepts(
     nlp: Language, name: str, data: Union[dict, list], topn: list, model_path: Union[str, None], ent_score: bool
 ):
-    return ConceptualSpacy(nlp=nlp, name=name, data=data, topn=topn, model_path=model_path, ent_score=ent_score)
+    return Conceptualizer(nlp=nlp, name=name, data=data, topn=topn, model_path=model_path, ent_score=ent_score)
